package com.mysoft.netty;

import com.google.gson.Gson;
import com.mysoft.config.Global;
import com.mysoft.entity.Equipment;
import com.mysoft.entity.NowData;
import com.mysoft.entity.RealTimeInformation;
import com.mysoft.entity.SystemConfig;
import com.mysoft.entity.WarningReport;
import com.mysoft.entity.WarnningType;
import com.mysoft.entity.WorkArea;
import com.mysoft.entity.utils.ConverterUtils;
import com.mysoft.entity.utils.DateStyle;
import com.mysoft.entity.utils.MyDateUtils;
import com.mysoft.mqtt.MqttPublisher;
import com.mysoft.mqtt.TopicType;
import com.mysoft.netty.DataReceiveServerPool;
import com.mysoft.netty.DataReceiveServer.1;
import com.mysoft.netty.DataReceiveServer.ChildChannelHandler;
import com.mysoft.service.EquipmentService;
import com.mysoft.service.NowDataService;
import com.mysoft.service.ParameterAssistantDisplayService;
import com.mysoft.service.SystemConfigService;
import com.mysoft.service.WarningReportService;
import com.mysoft.service.WarnningTypeService;
import com.mysoft.service.WorkAreaService;
import com.mysql.jdbc.StringUtils;
import io.netty.bootstrap.ServerBootstrap;
import io.netty.channel.ChannelFuture;
import io.netty.channel.ChannelOption;
import io.netty.channel.nio.NioEventLoopGroup;
import io.netty.channel.socket.nio.NioServerSocketChannel;
import java.nio.ByteBuffer;
import java.util.Date;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Map.Entry;
import java.util.concurrent.Executors;
import java.util.concurrent.ScheduledExecutorService;
import java.util.concurrent.TimeUnit;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import redis.clients.jedis.Jedis;

public class DataReceiveServer {

   public static Map mapEquipments;
   EquipmentService equipmentService;
   NowDataService nowDataService;
   ParameterAssistantDisplayService parameterAssistantDisplayService;
   WarnningTypeService warnningTypeService;
   WarningReportService warningReportService;
   SystemConfigService systemConfigService;
   WorkAreaService workAreaService;


   public void init() {
      this.initMqttClient();
      if(this.equipmentService == null) {
         this.equipmentService = new EquipmentService();
      }

      if(this.nowDataService == null) {
         this.nowDataService = new NowDataService();
      }

      if(this.parameterAssistantDisplayService == null) {
         this.parameterAssistantDisplayService = new ParameterAssistantDisplayService();
      }

      if(this.warnningTypeService == null) {
         this.warnningTypeService = new WarnningTypeService();
      }

      if(this.warningReportService == null) {
         this.warningReportService = new WarningReportService();
      }

      if(this.systemConfigService == null) {
         this.systemConfigService = new SystemConfigService();
      }

      if(this.workAreaService == null) {
         this.workAreaService = new WorkAreaService();
      }

      this.iniSysConfig();
      mapEquipments = new HashMap();
      List equipments = this.equipmentService.findlist(new Equipment());
      Integer size = Integer.valueOf(equipments == null?0:equipments.size());
      System.out.println("总共:" + size + "台设备");
      Iterator jedis = equipments.iterator();

      while(jedis.hasNext()) {
         Equipment gson = (Equipment)jedis.next();
         NowData lastTime = this.nowDataService.getModelByTerminalCode(gson.getTerminalCode());
         gson.setNowData(lastTime);
         gson.setDisplays(this.parameterAssistantDisplayService.getParametersByEquipmentCode(gson));
         List reports = this.warningReportService.getLatestWarnningReport(gson);
         WarnningType entry = new WarnningType();
         entry.setEquipmentType(gson.getEquipmentType());
         HashMap cacheRuntimeInfos = new HashMap();
         List warnningTypes = this.warnningTypeService.finWarnningTypeByEquipmentType(entry.getEquipmentType());
         Iterator mapEntry = warnningTypes.iterator();

         while(mapEntry.hasNext()) {
            WarnningType item = (WarnningType)mapEntry.next();
            item.setWarnning(false);
            cacheRuntimeInfos.put(item.getCode(), item);
         }

         if(reports != null) {
            for(int var19 = 0; var19 < reports.size(); ++var19) {
               if(cacheRuntimeInfos.containsKey(((WarningReport)reports.get(var19)).getWarningType().getCode())) {
                  ((WarnningType)cacheRuntimeInfos.get(((WarningReport)reports.get(var19)).getWarningType().getCode())).setWarnning(true);
               }
            }
         }

         gson.setWarnningTypes(cacheRuntimeInfos);
         mapEquipments.put(gson.getTerminalCode(), gson);
      }

      this.loadWorkAreas();
      Jedis var12 = new Jedis(Global.getConfig("redisHost"), Integer.parseInt(Global.getConfig("redisPort")));
      Gson var13 = new Gson();
      String var14 = var12.get("lastTimeForTj");
      if(var14 != null && MyDateUtils.getIntervalSecondsF(MyDateUtils.StringToDate(var14), new Date()) < 600.0D) {
         System.out.println("最新缓存时间:" + var14);
         Iterator var15 = mapEquipments.entrySet().iterator();

         while(var15.hasNext()) {
            Entry var16 = (Entry)var15.next();
            Map var17 = var12.hgetAll((String)var16.getKey() + "-tj");
            Iterator var18 = var17.entrySet().iterator();

            while(var18.hasNext()) {
               Entry var20 = (Entry)var18.next();
               DataReceiveServerPool.addRealTimeInformation((String)var16.getKey(), (String)var20.getKey(), (RealTimeInformation)var13.fromJson((String)var20.getValue(), RealTimeInformation.class));
            }
         }

         System.out.println("缓存加载完毕! " + MyDateUtils.DateToString(new Date(), DateStyle.YYYY_MM_DD_HH_MM_SS));
      }

   }

   private void initMqttClient() {
      MqttPublisher publisher = MqttPublisher.getInstance();
      publisher.subscribe(TopicType.SysConfigChanged, 0);
      publisher.subscribe(TopicType.WorkAreaChanged, 0);
   }

   private void iniSysConfig() {
      List systemConfigs = this.systemConfigService.findlist(new SystemConfig());
      Global.init();
      Iterator var2 = systemConfigs.iterator();

      while(var2.hasNext()) {
         SystemConfig config = (SystemConfig)var2.next();
         Global.addConfig(config.getName(), config.getValue());
      }

   }

   private void loadWorkAreas() {
      List workAreas = this.workAreaService.findList(new WorkArea());
      if(workAreas != null) {
         Iterator var2 = workAreas.iterator();

         while(var2.hasNext()) {
            WorkArea area = (WorkArea)var2.next();
            String id = area.getId();
            if(area.getArea() != null && !"".equals(area.getArea())) {
               area.setAreaPoints(ConverterUtils.ParsePoints(area.getArea()));
               DataReceiveServerPool.workAreas.put(id, area);
            }
         }
      }

   }

   public void bind(int port) throws Exception {
      NioEventLoopGroup bossGroup = new NioEventLoopGroup();
      NioEventLoopGroup childGroup = new NioEventLoopGroup();

      try {
         ServerBootstrap serverBootstrap = new ServerBootstrap();
         ((ServerBootstrap)((ServerBootstrap)serverBootstrap.group(bossGroup, childGroup).channel(NioServerSocketChannel.class)).option(ChannelOption.SO_BACKLOG, Integer.valueOf(1024))).childHandler(new ChildChannelHandler(this, (1)null));
         ChannelFuture f = serverBootstrap.bind(port).sync();
         System.out.println(new Date() + " Server started at:" + port);
         f.channel().closeFuture().sync();
      } finally {
         bossGroup.shutdownGracefully();
         childGroup.shutdownGracefully();
      }

   }

   public static void main(String[] args) throws Exception {
      Logger logger = LoggerFactory.getLogger(DataReceiveServer.class);
      Test();

      try {
         logger.error("日志测试!");
         DataReceiveServer ex = new DataReceiveServer();
         ex.init();
         int port = Global.getPortNo().intValue();
         ex.checkEquipmentOnlinStatus();
         DataReceiveServerPool.startShowLoadingInfo();
         DataReceiveServerPool.syncMincarWorkStatus();
         (new DataReceiveServer()).bind(port);
      } catch (Exception var4) {
         logger.error("系统异常!" + var4.toString());
         System.out.println("系统异常!");
         var4.printStackTrace();
      }

   }

   public static void Test() {
      Integer code = ConverterUtils.toInt("70000001", Integer.valueOf(0));
      ByteBuffer buffer = ByteBuffer.allocate(1024);
      buffer.put((byte)-1);
      buffer.put((byte)-1);
      buffer.putInt(1000);
      buffer.put((byte)-2);
      buffer.put((byte)-2);
      buffer.flip();
      byte[] tbyte = new byte[buffer.limit()];
      buffer.get(tbyte);
      byte[] bytes = buffer.array();
   }

   public void checkEquipmentOnlinStatus() {
      Logger logger = LoggerFactory.getLogger(DataReceiveServer.class);
      1 runnable = new 1(this);
      ScheduledExecutorService service = Executors.newSingleThreadScheduledExecutor();
      service.scheduleAtFixedRate(runnable, 0L, 60L, TimeUnit.SECONDS);
   }

   public static Equipment getEquipmentByQxId(String qxId) {
      if(StringUtils.isEmptyOrWhitespaceOnly(qxId)) {
         return null;
      } else {
         Iterator var1 = mapEquipments.values().iterator();

         Equipment equipment;
         do {
            if(!var1.hasNext()) {
               return null;
            }

            equipment = (Equipment)var1.next();
         } while(!qxId.equals(equipment.getQxid()));

         return equipment;
      }
   }
}
